@@ -32,11 +32,14 @@ SAB :: <include|exclude> <source1, source2, ... sourceN>
 
 REL :: <include|exclude> <relation1, relation2, ... relationN>
 
+RELA :: <include|exclude> <rela1, rela2, ... relaN>  (optional)
+
 For example, if we wanted to use the MSH vocabulary with only 
 the RB/RN relations, the configuration file would be:
 
 SAB :: include MSH
 REL :: include RB, RN
+RELA:: include inverse_isa, isa
 
 or 
 
@@ -212,11 +215,10 @@ if(defined $opt_socket) {
 }
 
 $umls = UMLS::Interface->new(\%option_hash); 
-die "Unable to create UMLS::Interface object.\n" if(!$umls);
-($errCode, $errString) = $umls->getError();
-die "$errString\n" if($errCode);
-
-&errorCheck($umls);
+if(!$umls) { 
+    print STDERR "Unable to create UMLS::Interface object.\n";
+    exit;
+}
 
 my @terms = ();
 if(defined $opt_file) {
@@ -244,25 +246,15 @@ foreach my $input (@terms) {
     else {
 	@c = $umls->getConceptList($input);
     }
-    
-    &errorCheck($umls);
-    
+        
     my $printFlag = 0;
     
     foreach my $cui (@c) {
 	
-	if($umls->validCui($cui)) {
-	    print STDERR "ERROR: The concept ($cui) is not valid.\n";
-	    exit;
-	}
-
-	#  make certain cui exists in this view
 	if($umls->exists($cui) == 0) { next; }	
 
 	my @children= $umls->getChildren($cui); 
 	
-	&errorCheck($umls);
-	
 	if($#children < 0) {
 	    print "The term $term ($cui) does not have any children\n";
 	}
@@ -273,7 +265,6 @@ foreach my $input (@terms) {
 		print "  $t ($child) ";
 		if(defined $opt_info) {
 		    my @relations = $umls->getRelationsBetweenCuis($cui, $child);
-		    &errorCheck($umls);
 		    print " => @relations";
 		}
 		print "\n";
@@ -287,15 +278,6 @@ foreach my $input (@terms) {
     }
 }
 
-sub errorCheck
-{
-    my $obj = shift;
-    ($errCode, $errString) = $obj->getError();
-    print STDERR "$errString\n" if($errCode);
-    exit if($errCode > 1);
-}
-
-
 ##############################################################################
 #  function to output minimal usage notes
 ##############################################################################
@@ -346,7 +328,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: getChildren.pl,v 1.12 2010/05/12 15:41:47 btmcinnes Exp $';
+    print '$Id: getChildren.pl,v 1.13 2010/05/24 17:57:16 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
